# -*-perl-*-
#
# Inventory verification test with filesystem target
#

use strict;
use Test::More;

use Brackup::Test;
use FindBin qw($Bin);
use Brackup::Util qw(tempfile);

############### Backup 1

my ($digdb_fh, $digdb_fn) = tempfile();
close($digdb_fh);
my $root_dir = "$Bin/data";
ok(-d $root_dir, "test data directory exists");
my ($backup_file, $backup, $target) = do_backup(
                            with_confsec => sub {
                                my $csec = shift;
                                $csec->add("path",          $root_dir);
                                $csec->add("chunk_size",    "2k");
                                $csec->add("digestdb_file", $digdb_fn);
                                $csec->add("ignore",        '\.svn');
                            },
                            with_targetsec => sub {
                                my $tsec = shift;
                                $tsec->add("type", 'Filesystem');
                                $tsec->add("inventorydb_type", $ENV{BRACKUP_TEST_INVENTORYDB_TYPE} || 'SQLite');
                            }
                            );

############### Verify inventory

my %stats = $target->verify_inventory;
ok(! $stats{bad}, "inventory ok, $stats{bad} / $stats{total} bad chunks found");

############### Inject bad entries into inventory

my $orphan_chunks_count = int(rand 10) + 1;
is(Brackup::Test::add_orphan_inventory_entries($target->inventory_db, $orphan_chunks_count), 
    $orphan_chunks_count, "added $orphan_chunks_count orphaned entries to inventory db");

############### Re-verify inventory, deleting bad chunks

%stats = $target->verify_inventory(delete => 1, quiet => 1);
is($stats{bad}, $orphan_chunks_count, "inventory not ok, $stats{bad}/$stats{total} bad chunks found (= orphan_chunks_count)");

############### Re-verify inventory all ok post-deletes

%stats = $target->verify_inventory;
ok(! $stats{bad}, "inventory ok, $stats{bad}/$stats{total} bad chunks found (all deleted)");


done_testing;

# vim:sw=4:et

